=============
Corpus Viewer
=============

.. figure:: icons/corpusviewer.png

Displays corpus content.

Signals
-------

**Inputs**:

-  **Data**

A corpus instance.

**Outputs**:

-  **Corpus**

A corpus instance.

Description
-----------

No description yet for this widget.

Example
-------

No example yet for this widget.
